@@ -36,7 +36,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("BankCard2EVerification", params)
+            headers = request.headers
+            body = self.call("BankCard2EVerification", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.BankCard2EVerificationResponse()
@@ -64,7 +65,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("BankCard4EVerification", params)
+            headers = request.headers
+            body = self.call("BankCard4EVerification", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.BankCard4EVerificationResponse()
@@ -92,7 +94,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("BankCardVerification", params)
+            headers = request.headers
+            body = self.call("BankCardVerification", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.BankCardVerificationResponse()
@@ -120,7 +123,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CheckBankCardInformation", params)
+            headers = request.headers
+            body = self.call("CheckBankCardInformation", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CheckBankCardInformationResponse()
@@ -148,7 +152,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CheckEidTokenStatus", params)
+            headers = request.headers
+            body = self.call("CheckEidTokenStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CheckEidTokenStatusResponse()
@@ -167,7 +172,7 @@ class FaceidClient(AbstractClient):
 
 
     def CheckIdCardInformation(self, request):
-        """传入身份证人像面照片，识别身份证照片上的信息，并将姓名、身份证号、身份证人像照片与公安权威库的证件照进行比对，是否属于同一个人，从而验证身份证信息的真实性。
+        """传入身份证人像面照片，识别身份证照片上的信息，并将姓名、身份证号、身份证人像照片与权威库的证件照进行比对，是否属于同一个人，从而验证身份证信息的真实性。
 
         :param request: Request instance for CheckIdCardInformation.
         :type request: :class:`tencentcloud.faceid.v20180301.models.CheckIdCardInformationRequest`
@@ -176,7 +181,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CheckIdCardInformation", params)
+            headers = request.headers
+            body = self.call("CheckIdCardInformation", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CheckIdCardInformationResponse()
@@ -204,7 +210,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CheckIdNameDate", params)
+            headers = request.headers
+            body = self.call("CheckIdNameDate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CheckIdNameDateResponse()
@@ -232,7 +239,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CheckPhoneAndName", params)
+            headers = request.headers
+            body = self.call("CheckPhoneAndName", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CheckPhoneAndNameResponse()
@@ -260,7 +268,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DetectAuth", params)
+            headers = request.headers
+            body = self.call("DetectAuth", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DetectAuthResponse()
@@ -278,37 +287,8 @@ class FaceidClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
-    def DetectReflectLivenessAndCompare(self, request):
-        """使用活体比对（光线）SDK生成的数据包检测活体，并和传入的图片进行比对。
-        图片和SDK生成的数据内容必须存储在腾讯云COS，COS Bucket所在的Region需要和本接口请求的Region保持一致，推荐使用生成上传链接接口来完成资源传递。
-
-        :param request: Request instance for DetectReflectLivenessAndCompare.
-        :type request: :class:`tencentcloud.faceid.v20180301.models.DetectReflectLivenessAndCompareRequest`
-        :rtype: :class:`tencentcloud.faceid.v20180301.models.DetectReflectLivenessAndCompareResponse`
-
-        """
-        try:
-            params = request._serialize()
-            body = self.call("DetectReflectLivenessAndCompare", params)
-            response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DetectReflectLivenessAndCompareResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(e.message, e.message)
-
-
     def EncryptedPhoneVerification(self, request):
-        """本接口用于校验手机号、姓名和身份证号的真实性和一致性，入参支持MD5加密传输。
+        """本接口用于校验手机号、姓名和身份证号的真实性和一致性，入参支持明文、MD5和SHA256加密传输。
 
         :param request: Request instance for EncryptedPhoneVerification.
         :type request: :class:`tencentcloud.faceid.v20180301.models.EncryptedPhoneVerificationRequest`
@@ -317,7 +297,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("EncryptedPhoneVerification", params)
+            headers = request.headers
+            body = self.call("EncryptedPhoneVerification", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.EncryptedPhoneVerificationResponse()
@@ -345,7 +326,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetActionSequence", params)
+            headers = request.headers
+            body = self.call("GetActionSequence", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetActionSequenceResponse()
@@ -373,7 +355,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetDetectInfo", params)
+            headers = request.headers
+            body = self.call("GetDetectInfo", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetDetectInfoResponse()
@@ -401,7 +384,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetDetectInfoEnhanced", params)
+            headers = request.headers
+            body = self.call("GetDetectInfoEnhanced", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetDetectInfoEnhancedResponse()
@@ -429,7 +413,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetEidResult", params)
+            headers = request.headers
+            body = self.call("GetEidResult", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetEidResultResponse()
@@ -457,7 +442,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetEidToken", params)
+            headers = request.headers
+            body = self.call("GetEidToken", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetEidTokenResponse()
@@ -485,7 +471,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetFaceIdResult", params)
+            headers = request.headers
+            body = self.call("GetFaceIdResult", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetFaceIdResultResponse()
@@ -513,7 +500,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetFaceIdToken", params)
+            headers = request.headers
+            body = self.call("GetFaceIdToken", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetFaceIdTokenResponse()
@@ -541,7 +529,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetLiveCode", params)
+            headers = request.headers
+            body = self.call("GetLiveCode", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetLiveCodeResponse()
@@ -569,7 +558,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetRealNameAuthResult", params)
+            headers = request.headers
+            body = self.call("GetRealNameAuthResult", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetRealNameAuthResultResponse()
@@ -597,7 +587,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetRealNameAuthToken", params)
+            headers = request.headers
+            body = self.call("GetRealNameAuthToken", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetRealNameAuthTokenResponse()
@@ -625,7 +616,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetWeChatBillDetails", params)
+            headers = request.headers
+            body = self.call("GetWeChatBillDetails", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetWeChatBillDetailsResponse()
@@ -653,7 +645,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("IdCardOCRVerification", params)
+            headers = request.headers
+            body = self.call("IdCardOCRVerification", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.IdCardOCRVerificationResponse()
@@ -681,7 +674,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("IdCardVerification", params)
+            headers = request.headers
+            body = self.call("IdCardVerification", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.IdCardVerificationResponse()
@@ -700,7 +694,7 @@ class FaceidClient(AbstractClient):
 
 
     def ImageRecognition(self, request):
-        """传入照片和身份信息，判断该照片与公安权威库的证件照是否属于同一个人。
+        """传入照片和身份信息，判断该照片与权威库的证件照是否属于同一个人。
 
         :param request: Request instance for ImageRecognition.
         :type request: :class:`tencentcloud.faceid.v20180301.models.ImageRecognitionRequest`
@@ -709,7 +703,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ImageRecognition", params)
+            headers = request.headers
+            body = self.call("ImageRecognition", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ImageRecognitionResponse()
@@ -737,7 +732,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("Liveness", params)
+            headers = request.headers
+            body = self.call("Liveness", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.LivenessResponse()
@@ -765,7 +761,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("LivenessCompare", params)
+            headers = request.headers
+            body = self.call("LivenessCompare", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.LivenessCompareResponse()
@@ -784,7 +781,7 @@ class FaceidClient(AbstractClient):
 
 
     def LivenessRecognition(self, request):
-        """传入视频和身份信息，先判断视频中是否为真人，判断为真人后，再判断该视频中的人与公安权威库的证件照是否属于同一个人。
+        """传入视频和身份信息，先判断视频中是否为真人，判断为真人后，再判断该视频中的人与权威库的证件照是否属于同一个人。
 
         :param request: Request instance for LivenessRecognition.
         :type request: :class:`tencentcloud.faceid.v20180301.models.LivenessRecognitionRequest`
@@ -793,7 +790,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("LivenessRecognition", params)
+            headers = request.headers
+            body = self.call("LivenessRecognition", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.LivenessRecognitionResponse()
@@ -821,7 +819,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("MinorsVerification", params)
+            headers = request.headers
+            body = self.call("MinorsVerification", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.MinorsVerificationResponse()
@@ -849,7 +848,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("MobileNetworkTimeVerification", params)
+            headers = request.headers
+            body = self.call("MobileNetworkTimeVerification", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.MobileNetworkTimeVerificationResponse()
@@ -877,7 +877,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("MobileStatus", params)
+            headers = request.headers
+            body = self.call("MobileStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.MobileStatusResponse()
@@ -895,6 +896,35 @@ class FaceidClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ParseNfcData(self, request):
+        """解析SDK获取到的证件NFC数据，接口传入SDK返回的ReqId，返回证件信息（个别字段为特定证件类型特有）。SDK生成的ReqId五分钟内有效，重复查询仅收一次费。支持身份证类证件（二代身份证、港澳居住证、台湾居住证、外国人永居证）以及旅行类证件（港澳通行证、台湾通行证、台胞证、回乡证）的NFC识别及核验。
+
+        :param request: Request instance for ParseNfcData.
+        :type request: :class:`tencentcloud.faceid.v20180301.models.ParseNfcDataRequest`
+        :rtype: :class:`tencentcloud.faceid.v20180301.models.ParseNfcDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ParseNfcData", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ParseNfcDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def PhoneVerification(self, request):
         """本接口用于校验手机号、姓名和身份证号的真实性和一致性。支持的手机号段详情请查阅<a href="https://cloud.tencent.com/document/product/1007/46063">运营商类</a>文档。
 
@@ -905,7 +935,8 @@ class FaceidClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PhoneVerification", params)
+            headers = request.headers
+            body = self.call("PhoneVerification", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PhoneVerificationResponse()
@@ -916,6 +947,93 @@ class FaceidClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def PhoneVerificationCMCC(self, request):
+        """本接口用于校验中国移动手机号、姓名和身份证号的真实性和一致性。中国移动支持的手机号段详情请查阅<a href="https://cloud.tencent.com/document/product/1007/46063">运营商类</a>文档。
+
+        :param request: Request instance for PhoneVerificationCMCC.
+        :type request: :class:`tencentcloud.faceid.v20180301.models.PhoneVerificationCMCCRequest`
+        :rtype: :class:`tencentcloud.faceid.v20180301.models.PhoneVerificationCMCCResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("PhoneVerificationCMCC", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.PhoneVerificationCMCCResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def PhoneVerificationCTCC(self, request):
+        """本接口用于校验中国电信手机号、姓名和身份证号的真实性和一致性。中国电信支持的手机号段详情请查阅<a href="https://cloud.tencent.com/document/product/1007/46063">运营商类</a>文档。
+
+        :param request: Request instance for PhoneVerificationCTCC.
+        :type request: :class:`tencentcloud.faceid.v20180301.models.PhoneVerificationCTCCRequest`
+        :rtype: :class:`tencentcloud.faceid.v20180301.models.PhoneVerificationCTCCResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("PhoneVerificationCTCC", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.PhoneVerificationCTCCResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def PhoneVerificationCUCC(self, request):
+        """本接口用于校验中国联通手机号、姓名和身份证号的真实性和一致性。中国联通支持的手机号段详情请查阅<a href="https://cloud.tencent.com/document/product/1007/46063">运营商类</a>文档。
+
+        :param request: Request instance for PhoneVerificationCUCC.
+        :type request: :class:`tencentcloud.faceid.v20180301.models.PhoneVerificationCUCCRequest`
+        :rtype: :class:`tencentcloud.faceid.v20180301.models.PhoneVerificationCUCCResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("PhoneVerificationCUCC", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.PhoneVerificationCUCCResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
